<!-- markdownlint-disable MD033 -->
<!-- markdownlint-disable MD041 -->

<h1 align="center">
  pipfile-sort
</h1>

<div align="center">
  <strong>
    Sort package dependency lists in Pipfile.
  </strong>
</div>
